==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/compton-conf/compton-conf_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language ="nl">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Instellingen van speciale effecten</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Schaduw</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="30"/>
        <source>The blur radius for shadows</source>
        <translation>De wazigheidsradius voor schaduwen</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="40"/>
        <source>The left offset for shadows</source>
        <translation>Het linkerverloop voor schaduwen</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="54"/>
        <source>The top offset for shadows</source>
        <translation>Het verloop voor schaduwen aan de bovenkant</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="68"/>
        <source>The translucency for shadows</source>
        <translation>De doorzichtigheid voor schaduwen</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="75"/>
        <source>Color of shadow</source>
        <translation>Schaduwkleur</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="89"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>Herstel wat raar gedoe met ARGB-vensters</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="92"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Schakel schaduwmasker achter venster uit</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="99"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>Teken geen schaduwen op DND-vensters</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="106"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Teken geen schaduwen op dok-/paneelvensters</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="113"/>
        <source>Enabled client-side shadows on windows</source>
        <translation>Ingeschakelde schaduwen op vensters</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="120"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Geen schaduwen op alle gevormde vensters</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="138"/>
        <source>Opacity</source>
        <translation>Ondoorzichtigheid</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="147"/>
        <source>The opacity for menus</source>
        <translation>De ondoorzichtigheid voor menu's</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="154"/>
        <source>Default opacity of inactive windows</source>
        <translation>Standaard-ondoorzichtigheid van inactieve vensters</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="161"/>
        <source>Default opacity for active windows</source>
        <translation>Standaard-doorzichtigheid voor actieve vensters</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="168"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Ondoorzichtigheid van titelbalken en randen van vensters</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="175"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>Achtergronddienst XRender: stapgrootte voor alfa-afbeeldingen
(verhogen kan resulteren in verminderd gebruik van systeemkracht door X)</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="183"/>
        <source>Dim inactive windows</source>
        <translation>Maak inactieve vensters doffer</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="190"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Mate van dofheid niet afhankelijk van ondoorzichtigheid van venster</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="197"/>
        <source>Blur background of transparent windows</source>
        <translation>Verwazig de achtergrond van doorzichtige vensters</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="204"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Verwazig ook de achtergrond van ondoorzichtige vensters met doorzichtige randen</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="211"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Mate van verwaziging onafhankelijk van ondoorzichtigheid van venster</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="279"/>
        <source>Fade</source>
        <translation>Wegsterven</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="285"/>
        <source>Fade windows during opacity changes</source>
        <translation>Laat vensters wegsterven gedurende veranderingen van de ondoorzichtigheid</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="292"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>De tijd tussen stappen in het wegsterven in milliseconden</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="299"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Verandering in ondoorzichtigheid bij stappen tijdens opdoemen</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="306"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Verandering in ondoorzichtigheid bij stappen tijdens wegsterven</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="313"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Laat vensters niet opdoemen of wegsterven bij openen en sluiten</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="356"/>
        <source>Other</source>
        <translation>Overig</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="362"/>
        <source>Not implemented yet</source>
        <translation>Nog niet ten uitvoer gebracht</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="375"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="179"/>
        <source>About ComptonConf</source>
        <translation>Over ComptonConf</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="180"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - instellingsgereedschap voor Compton

Auteursrecht (c) 2013
Auteur: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/compton-conf/compton-conf_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Instellingen van speciale effecten</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Schaduw</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="67"/>
        <source>The blur radius for shadows</source>
        <translation>De wazigheidsradius voor schaduwen</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="77"/>
        <source>The left offset for shadows</source>
        <translation>Het linkerverloop voor schaduwen</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="91"/>
        <source>The top offset for shadows</source>
        <translation>Het verloop voor schaduwen aan de bovenkant</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="105"/>
        <source>The translucency for shadows</source>
        <translation>De doorzichtigheid voor schaduwen</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="122"/>
        <source>Color of shadow</source>
        <translation>Schaduwkleur</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="57"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>Herstel wat raar gedoe met ARGB-vensters</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="60"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Schakel schaduwmasker achter venster uit</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="50"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>Teken geen schaduwen op DND-vensters</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="43"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Teken geen schaduwen op dok-/paneelvensters</translation>
    </message>
    <message>
        <source>Enabled client-side shadows on windows</source>
        <translation type="vanished">Ingeschakelde schaduwen op vensters</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="36"/>
        <source>Enable client-side shadows on windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="136"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Geen schaduwen op alle gevormde vensters</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="143"/>
        <source>Crop shadows of maximized windows from extended displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="151"/>
        <source>Opacity</source>
        <translation>Ondoorzichtigheid</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="160"/>
        <source>The opacity for menus</source>
        <translation>De ondoorzichtigheid voor menu&apos;s</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="167"/>
        <source>Default opacity of inactive windows</source>
        <translation>Standaard-ondoorzichtigheid van inactieve vensters</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="174"/>
        <source>Default opacity for active windows</source>
        <translation>Standaard-doorzichtigheid voor actieve vensters</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="181"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Ondoorzichtigheid van titelbalken en randen van vensters</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="188"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>Achtergronddienst XRender: stapgrootte voor alfa-afbeeldingen
(verhogen kan resulteren in verminderd gebruik van systeemkracht door X)</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="196"/>
        <source>Dim inactive windows</source>
        <translation>Maak inactieve vensters doffer</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="203"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Mate van dofheid niet afhankelijk van ondoorzichtigheid van venster</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="210"/>
        <source>Blur background of transparent windows</source>
        <translation>Verwazig de achtergrond van doorzichtige vensters</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="217"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Verwazig ook de achtergrond van ondoorzichtige vensters met doorzichtige randen</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="224"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Mate van verwaziging onafhankelijk van ondoorzichtigheid van venster</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="292"/>
        <source>Fade</source>
        <translation>Wegsterven</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="298"/>
        <source>Fade windows during opacity changes</source>
        <translation>Laat vensters wegsterven gedurende veranderingen van de ondoorzichtigheid</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="305"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>De tijd tussen stappen in het wegsterven in milliseconden</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="312"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Verandering in ondoorzichtigheid bij stappen tijdens opdoemen</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="319"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Verandering in ondoorzichtigheid bij stappen tijdens wegsterven</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="326"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Laat vensters niet opdoemen of wegsterven bij openen en sluiten</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="369"/>
        <source>Other</source>
        <translation>Overig</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="381"/>
        <source>Rendering backend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="393"/>
        <source>X Render</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="400"/>
        <source>GLX (OpenGL)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not implemented yet</source>
        <translation type="vanished">Nog niet ten uitvoer gebracht</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="416"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="209"/>
        <source>About ComptonConf</source>
        <translation>Over ComptonConf</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="210"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - instellingsgereedschap voor Compton

Auteursrecht (c) 2013
Auteur: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>
